import os
import sys
from setuptools import find_packages, setup

from version import __version__

BASEDIR = os.path.dirname(__file__)

requirements = [
    'Flask>=2.0.2',
    'qPython3>=1.0.0',
    'numpy>=1.8.0'
]

setup(
    name='Flask-kdb',
    url='http://www.github.com/ryanmcfarland/flask-kdb/',
    author='Ryan McFarland',
    author_email='ryanmcfarland@outlook.com',
    description='kdb+ connections within a Flask application.',
    long_description=open(os.path.join(BASEDIR, 'readme.md')).read(),
    long_description_content_type='text/markdown',
    version=__version__,
    license='MIT License',
    keywords=['flask', 'kdb', 'kdb+', 'q', 'qpython'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Framework :: Flask',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development',
    ],
    include_package_data=True,
    packages=find_packages(exclude=("tests",)),
    install_requires=requirements,
)


from qpython.qconnection import QConnection

# https://stackoverflow.com/questions/55523299/best-practices-for-persistent-database-connections-in-python-when-using-flask

class FlaskKDB:
    """ Connection Class to connect to a KDB instance from a Flask App

    :Parameters:
    - `app`  : flask app, required
    - `host`  : kdb host, optional | defined via env variable KDB_HOST
    - `port` : kdb host, optional | defined via env variable KDB_PORT
    """
    def __init__(self, app=None, host=None, port=None):
        self.app=app
        self.host=host
        self.port=port
        if app is not None:
            self.init_app(app, self.host, self.port)
        elif host and port:
            self.connect()

    def init_app(self, app, host=None, port=None):
        self.host = host or self.host or app.config["KDB_HOST"]
        self.port = port or self.port or int(app.config["KDB_PORT"])
        self.connect()

    def get_db(self):
        if not self.conn:
            self.connect()
        return self

    def close_db(self):
        if self.conn:
            self.conn.close()

    def connect(self):
        self.conn =  QConnection(host=self.host, port=self.port)
        self.conn.open()

    def sendSync(self, qry):
        if not self.conn:
            self.connect()
        return self.conn.sendSync(qry)